require("ggplot2")
require("dplyr")

data <- read.csv("/Users/bouchard/w/blogobayes/www/ex/be/results/all/LaunchPrediction-1927151314/samples/nextLaunch.csv")

# ggplot has bad default sizes for large facetting
verticalSize <- 2.0 *  1 
horizontalSize <- 4.0

n_samples <- max(data$sample)
cut_off <- n_samples * 0.5
data <- subset(data, sample > cut_off)
normalization <-  max(data$sample) - n_samples * 0.5
data <- data %>%
  group_by(value) %>%
  summarise(
    probability = n() / normalization
  )
hdi_upper <- function(samples) {
	n = length(samples)
	m = as.integer(0.9 * n)
	sorted_samples <- sort(samples)
  shortest_length <- Inf
  shortest_interval <- c()
  for (i in 1:(n-m)){
    lower <- sorted_samples[i]
    upper <- sorted_samples[i+m]
    interval_length <- upper - lower
    if (interval_length < shortest_length) {
      shortest_length <- interval_length
      shortest_interval <- c(lower, upper)
    }
  }
return (shortest_interval[2])
}
hdi_lower <- function(samples) {
	n = length(samples)
	m = as.integer(0.9 * n)
	sorted_samples <- sort(samples)
  shortest_length <- Inf
  shortest_interval <- c()
  for (i in 1:(n-m)){
    lower <- sorted_samples[i]
    upper <- sorted_samples[i+m]
    interval_length <- upper - lower
    if (interval_length < shortest_length) {
      shortest_length <- interval_length
      shortest_interval <- c(lower, upper)
    }
  }
return (shortest_interval[1])
}
hdi_df <- data %>% group_by() %>%
 summarise(HDI.lower=hdi_lower(value),
           HDI.upper=hdi_upper(value))


p <- ggplot(data, aes(x = value, y = probability, xend = value, yend = rep(0, length(probability)))) +
  geom_point() + geom_segment() + 
  geom_segment(data = hdi_df, aes(x=HDI.lower, xend=HDI.upper, y=0, yend=0), col="red") + 
  theme_bw() + 
  xlab("nextLaunch") +
  ylab("probability") +
  ggtitle("Probability mass function plot for: nextLaunch")
ggsave("/Users/bouchard/w/blogobayes/www/ex/be/results/all/LaunchPrediction-1927151314/posteriorPlots/nextLaunch.pdf", limitsize = F, height = verticalSize, width = horizontalSize)
